@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 
-
 __author__ = "Connor Morgan-Lang and Kishori Konwar"
 __maintainer__ = "Connor Morgan-Lang"
 __license__ = "GPL-3.0"
@@ -23,10 +22,9 @@ try:
     from os.path import isfile, join
     from time import gmtime, strftime
 
-    from .treesapp_args import TreeSAPPArgumentParser
     from .classy import CommandLineWorker, CommandLineFarmer, ItolJplace, NodeRetrieverWorker,\
         TreeLeafReference, TreeProtein, MarkerBuild
-    from .fasta import format_read_fasta, get_headers, write_new_fasta, read_fasta_to_dict, FASTA
+    from .fasta import get_headers, write_new_fasta, read_fasta_to_dict, FASTA
     from .entish import create_tree_info_hash, deconvolute_assignments, read_and_understand_the_reference_tree,\
         get_node, annotate_partition_tree, find_cluster, tree_leaf_distances, index_tree_edges
     from .external_command_interface import launch_write_command
@@ -1613,17 +1611,6 @@ def abundify_tree_saps(tree_saps: dict, abundance_dict: dict):
     return
 
 
-def get_reference_sequence_dict(args, update_tree):
-    # Determine the name of the aligned FASTA with reference sequences
-    ref_alignment_fasta = "data" + os.sep + "alignment_data" + os.sep + update_tree.COG + ".fa"
-    # Read the FASTA to get headers and sequences
-    ref_fasta_dict = format_read_fasta(ref_alignment_fasta, update_tree.marker_molecule, args.output)
-    # Strip the '-'s since these will be re-aligned again
-    unaligned_ref_seqs = {header: re.sub('-', '', ref_fasta_dict[header]) for header in ref_fasta_dict}
-
-    return unaligned_ref_seqs
-
-
 def create_itol_labels(marker, itol_base_dir, tree_data_dir):
     """
     Create the marker_labels.txt file for each marker gene that was used for classification
